<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="160"/>
        <source>License</source>
        <translation>Licenco</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="840"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>La dosiero estas ligilo set ĝia celo ne ekzistas.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1261"/>
        <location filename="../../backends.cpp" line="1293"/>
        <location filename="../../backends.cpp" line="1337"/>
        <source>Could not read archive</source>
        <translation>La arkivo ne legeblis</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1296"/>
        <location filename="../../backends.cpp" line="1342"/>
        <source>Archive Loaded</source>
        <translation>Arkivo Ŝargita</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1303"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Modification Finished</source>
        <translation>Modifado Farita</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1324"/>
        <location filename="../../backends.cpp" line="1359"/>
        <source>Extraction Finished</source>
        <translation>Ekstraktado Farita</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1327"/>
        <location filename="../../backends.cpp" line="1378"/>
        <source>Extraction Failed</source>
        <translation>Ekstraktado Malsukcesis</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1475"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1 mankas al via sistemo.
Bonvole insatlu ĝin por ĉi tia arkivo!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Vi povas tajpi en la ĉefan vidon.
Viŝu la tekston per la eskapa klavo.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Startu kun ĉi tiu grando:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>Uzu sistemajn ikonojn kie eblas</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>Avertu antaŭ ol forigi erojn</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Malmarku por ekspansii nur la suprajn dosierujojn.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>Ekspansiu ĉiujn dosierujojn malfermante arkivojn</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Lasu ĉi tion malplena por la defaŭlto.

Averto: Arqiver ne funkcius se la
duumaĵo ne apartenus al libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>Duumaĵo de libarchive:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Memoru la &amp;grandon de la fenestro</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>La grando de vid-ikonoj:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="62"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="184"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Restartigo de la aplikaĵo necesas por ke la ŝanĝoj efektiviĝu.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="241"/>
        <source>Select libarchive binary</source>
        <translation>Elekti duumaĵon de libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Arkivo:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Filtru Dosierojn...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>R&amp;edakti</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>&amp;Vido</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Malfermi Arkivon</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Nova Arkivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Forlasi</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>Aldoni Dosiero(j)n</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>Forviŝi Doesiero(j)n</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>Ekstrakti ĉion</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>Aldoni Dosierujon</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>Ekstrakti Elekton</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>Aldoni Pasvorton</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>E&amp;kspansii</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>Kolap&amp;si</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Kopii Ĉi Tiun Padon</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>Haltigi &amp;Procezon</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>Ĝisdatigi Arkivon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="147"/>
        <source>Root</source>
        <translation>Radiko</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="252"/>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>File</source>
        <translation>Dosiero</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>MimeType</source>
        <translation>Mime-tipo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>Size</source>
        <translation>Grando</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="553"/>
        <location filename="../../mainWin.cpp" line="838"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>Malfermadi Arkivon...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="767"/>
        <source>Create Archive</source>
        <translation>Estigi Arkivon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="464"/>
        <location filename="../../mainWin.cpp" line="793"/>
        <location filename="../../mainWin.cpp" line="992"/>
        <location filename="../../mainWin.cpp" line="1300"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="794"/>
        <source>The following archive already exists:</source>
        <translation>La jana arkivo jam ekzistas:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="796"/>
        <source>Do you want to replace it?
</source>
        <translation>Ĉu vi volas anstataŭigi ĝin?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="830"/>
        <source>Open Archive</source>
        <translation>Malfermi Arkivon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="941"/>
        <source>Add to Archive</source>
        <translation>Aldoni al Arkivon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="936"/>
        <location filename="../../mainWin.cpp" line="967"/>
        <location filename="../../mainWin.cpp" line="1252"/>
        <location filename="../../mainWin.cpp" line="1258"/>
        <source>Adding Items...</source>
        <translation>Aldoni Erojn...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="993"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Ĉu vi volas forigi la elektita(j)n ero(j)n?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1012"/>
        <source>Removing Items...</source>
        <translation>Forviŝi Erojn...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1215"/>
        <location filename="../../mainWin.cpp" line="1230"/>
        <location filename="../../mainWin.cpp" line="1315"/>
        <location filename="../../mainWin.cpp" line="1329"/>
        <source>Extracting...</source>
        <translation>Ekstrakti...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1056"/>
        <source>Copy Archive Path</source>
        <translation>Kopiu la Arkivpadon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <source>Some files have been modified.</source>
        <translation>Dosieroj estas modifitaj.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>Ĉu vi volas ignori la ŝanĝojn?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>All Types</source>
        <translation>Ĉiuj Tipoj</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="637"/>
        <location filename="../../mainWin.cpp" line="661"/>
        <source>Uncompressed Archive</source>
        <translation>Nekompaktigita Arkivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>GZip Compressed Archive</source>
        <translation>Kompaktigita Arkivo de GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <source>BZip Compressed Archive</source>
        <translation>Kompaktigita Arkivo de BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Kompaktigita Arkivo de BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>LMZA Compressed Archive</source>
        <translation>Kompaktigita Arkivo de LMZA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>XZ Compressed Archive</source>
        <translation>Kompaktigita Arkivo de XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Kompaktigita Arkivo de Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>CPIO Archive</source>
        <translation>Arkivo de CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="646"/>
        <location filename="../../mainWin.cpp" line="678"/>
        <source>AR Archive</source>
        <translation>Arkivo de AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="648"/>
        <location filename="../../mainWin.cpp" line="680"/>
        <source>Zip Archive</source>
        <translation>Arkivo de Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>Gzip Archive</source>
        <translation>Arkivo de Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>7-Zip Archive</source>
        <translation>Arkivo de 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="666"/>
        <location filename="../../mainWin.cpp" line="667"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>NURLEGA: Arkivo de BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>NURLEGA: Arkivo de BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>NURLEGA: BZip2-Kompaktigita PDF-Dokumento</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>NURLEGA: Arkivo de XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>NURLEGA: XZ-Kompaktigita PDF-Dokumento</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>NURLEGA: Arkivo de Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Gzip-Kompaktigita PDF-Dokumento</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>NURLEGA: Kompaktigita SVG-Bildo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>NURLEGA: ISO-Kopio</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>NURLEGA: Arkivo de XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>NURLEGA: Arkivo de Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>NURLEGA: Pakaĵo de Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <location filename="../../mainWin.cpp" line="693"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>NURLEGA: Pakaĵo de RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="694"/>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>NURLEGA: MS-Vindoza Ekzekveblaĵo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>NURLEGA: MS-Vindoza Instala Pakaĵo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>NURLEGA: MS-Vindoza Kabineta Arkivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: Android Package</source>
        <translation>NURLEGA: Pakaĵo de Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>NURLEGA: Arkivo de RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>NURLEGA: Aplikaĵa Pakaĵo de AppImage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>NURLEGA: Kromprograma Pakaĵo de VirtualBox</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="712"/>
        <source>All Known Types</source>
        <translation>Ĉiuj Konitaj tipoj</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="717"/>
        <source>Show All Files</source>
        <translation>Montri Ĉiujn Dosierojn</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1066"/>
        <source>Open Containing Folder</source>
        <translation>Malfermu la Enhavan Dosierujon</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>Vidi Ĉi Tiun Eron</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1111"/>
        <location filename="../../mainWin.cpp" line="1119"/>
        <source>Enter Password</source>
        <translation>Enmetu Pasvorton</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1127"/>
        <source>Cancel</source>
        <translation>Rezigni</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1132"/>
        <source>OK</source>
        <translation>Bone</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1136"/>
        <source>Encrypt the file list</source>
        <translation>Ĉifri la dosierliston</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1137"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Ĉi tio efektiviĝos post kiam dosieroj/dosierujoj estas aldonitaj.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1208"/>
        <location filename="../../mainWin.cpp" line="1284"/>
        <source>Extract Into Directory</source>
        <translation>Ekstrakto en Dosierujon</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1301"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Dosieroj estos anstataŭigitaj.
Ĉu vi volas pluiri?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1427"/>
        <source>Link To: %1</source>
        <translation>Ligilo Al %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1694"/>
        <source>Could not read archive</source>
        <translation>La arkivo ne legeblis</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1765"/>
        <source>A simple Qt archive manager</source>
        <translation>Simpla Qt-Arkivilo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1766"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>bazita sur libarchive, gzip kaj 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1767"/>
        <source>Author</source>
        <translation>Verkinto</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1768"/>
        <source>aka.</source>
        <translation>akk.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <location filename="../../mainWin.cpp" line="1770"/>
        <source>About Arqiver</source>
        <translation>Pri Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <source>Translators</source>
        <translation>Tradukintoj</translation>
    </message>
</context>
</TS>
